/* tslint:disable */
/* eslint-disable */
export const memory: WebAssembly.Memory;
export function create_segwit_bond_spec(a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number): void;
export function inspect_bond(a: number, b: number, c: number): void;
export function bond_address(a: number, b: number, c: number, d: number, e: number): void;
export function create_bitcoin_utxo(a: number, b: number, c: number, d: number): void;
export function create_elements_utxo(a: number, b: number, c: number, d: number): void;
export function create_burn_tx(a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number, l: number, m: number, n: number, o: number, p: number, q: number, r: number): void;
export function create_unsigned_reclaim_tx(a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number): void;
export function finalize_ecdsa_reclaim_tx(a: number, b: number, c: number, d: number, e: number, f: number, g: number): void;
export function create_signed_ecdsa_reclaim_tx(a: number, b: number, c: number, d: number, e: number, f: number, g: number, h: number, i: number, j: number, k: number, l: number): void;
export function rustsecp256k1zkp_v0_8_0_default_illegal_callback_fn(a: number, b: number): void;
export function rustsecp256k1zkp_v0_8_0_default_error_callback_fn(a: number, b: number): void;
export function rustsecp256k1_v0_8_1_context_create(a: number): number;
export function rustsecp256k1_v0_8_1_context_destroy(a: number): void;
export function rustsecp256k1_v0_8_1_default_illegal_callback_fn(a: number, b: number): void;
export function rustsecp256k1_v0_8_1_default_error_callback_fn(a: number, b: number): void;
export function __wbindgen_malloc(a: number, b: number): number;
export function __wbindgen_realloc(a: number, b: number, c: number, d: number): number;
export function __wbindgen_add_to_stack_pointer(a: number): number;
export function __wbindgen_free(a: number, b: number, c: number): void;
export function __wbindgen_exn_store(a: number): void;
